@@ -35,6 +35,10 @@ class Grammar(object):
         """
         p[0] = ast.Field(str(p[1]))
 
+    def p_jmespath_or_expression(self, p):
+        """expression : expression OR expression"""
+        p[0] = ast.ORExpression(p[1], p[3])
+
     def p_error(self, t):
         raise ValueError(
             'Parse error at column %s near token %s (%s)' % (
@@ -77,7 +81,7 @@ class Parser(object):
     def _free_cache_entries(self):
         # This logic is borrowed from the new regex library which
         # uses similar eviction strategies.
-        for key in random.sample(self._cache.keys(), self._max_size / 2):
+        for key in random.sample(self._cache.keys(), int(self._max_size / 2)):
             del self._cache[key]
 
     @classmethod
